unit main;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  Moon, StdCtrls, ExtCtrls;

type
  TMainForm = class(TForm)
    Moon: TMoon;
    HemisphereRadio: TRadioGroup;
    DisplayTypeRadio: TRadioGroup;
    Panel1: TPanel;
    PhaseLabel: TLabel;
    PhaseEdit: TEdit;
    CycleButton: TButton;
    Panel2: TPanel;
    TimeLabel: TLabel;
    TimeEdit: TEdit;
    NowButton: TButton;
    ExitButton: TButton;
    Timer: TTimer;
    procedure ExitButtonClick(Sender: TObject);
    procedure ChangeHemisphere(Sender: TObject);
    procedure EnableDisable(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure PhaseAngleChange(Sender: TObject);
    procedure CycleButtonClick(Sender: TObject);
    procedure TimeChange(Sender: TObject);
    procedure RightAboutNow(Sender: TObject);
  private

  public
    lPhase : extended;
    procedure AnimateMoon(Sender : TObject);
    procedure StopMoon;

  end;

var
  MainForm: TMainForm;

implementation

{$R *.DFM}

procedure TMainForm.AnimateMoon;
begin
  Moon.Phase := lPhase;
  lPhase := lPhase + 0.1;
  if lPhase > 2 * pi
    then StopMoon;
end;

procedure TMainForm.StopMoon;
begin
  Timer.Enabled := FALSE;
  Timer.OnTimer := nil;
  PhaseEdit.Text := '0.0';
  CycleButton.Enabled := TRUE;
  PhaseEdit.Enabled := TRUE;
  DisplayTypeRadio.Enabled := TRUE;
  MainForm.Cursor := crDefault;
end;

procedure TMainForm.ExitButtonClick(Sender: TObject);
begin
  close;
end;

procedure TMainForm.ChangeHemisphere(Sender: TObject);
begin
  if HemisphereRadio.ItemIndex = 1
    then Moon.Hemisphere := heSouthern
    else Moon.Hemisphere := heNorthern;
end;

procedure TMainForm.EnableDisable(Sender: TObject);
begin
  PhaseLabel.Enabled := DisplayTypeRadio.ItemIndex = 1;
  PhaseEdit.Enabled := DisplayTypeRadio.ItemIndex = 1;
  CycleButton.Enabled := DisplayTypeRadio.ItemIndex = 1;

  TimeLabel.Enabled := DisplayTypeRadio.ItemIndex = 2;
  TimeEdit.Enabled := DisplayTypeRadio.ItemIndex = 2;
  NowButton.Enabled := DisplayTypeRadio.ItemIndex = 2;

  case DisplayTypeRadio.ItemIndex of
    0:
      Moon.MoonDisplayType := mdtUseSystemTime;

    1:
      Moon.MoonDisplayType := mdtUsePhaseAngle;

    2:
      Moon.MoonDisplayType := mdtUseCustomTime;

  end;  //  case
end;

procedure TMainForm.FormCreate(Sender: TObject);
begin
  EnableDisable(Sender);
end;

procedure TMainForm.PhaseAngleChange(Sender: TObject);
begin
  if PhaseEdit.Text <> ''
    then Moon.Phase := StrToFloat(PhaseEdit.Text);
end;

procedure TMainForm.CycleButtonClick(Sender: TObject);
begin
  CycleButton.Enabled := FALSE;
  PhaseEdit.Enabled := FALSE;
  DisplayTypeRadio.Enabled := FALSE;
  MainForm.Cursor := crHourGlass;
  lPhase := 0;
  Timer.OnTimer := AnimateMoon;
  Timer.Enabled := TRUE;
end;

procedure TMainForm.TimeChange(Sender: TObject);
begin
  if TimeEdit.Text <> ''
    then Moon.CustomTime := TimeEdit.Text; 
end;

procedure TMainForm.RightAboutNow(Sender: TObject);
begin
  TimeEdit.Text := DateTimeToStr(Now);
end;

end.
